// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_KUSERFEEDBACK_LOG_LOGGING_P_H
#define ECM_QLOGGINGCATEGORY_KUSERFEEDBACK_LOG_LOGGING_P_H

#include <QLoggingCategory>
 namespace KUserFeedback {
Q_DECLARE_LOGGING_CATEGORY(Log)
} 

#endif
