/********************************************************************************
** Form generated from reading UI file 'feedbackconfigdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FEEDBACKCONFIGDIALOG_H
#define UI_FEEDBACKCONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QVBoxLayout>
#include "feedbackconfigwidget.h"

namespace KUserFeedback {

class Ui_FeedbackConfigDialog
{
public:
    QVBoxLayout *verticalLayout;
    KUserFeedback::FeedbackConfigWidget *configWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *KUserFeedback__FeedbackConfigDialog)
    {
        if (KUserFeedback__FeedbackConfigDialog->objectName().isEmpty())
            KUserFeedback__FeedbackConfigDialog->setObjectName("KUserFeedback__FeedbackConfigDialog");
        KUserFeedback__FeedbackConfigDialog->resize(584, 536);
        verticalLayout = new QVBoxLayout(KUserFeedback__FeedbackConfigDialog);
        verticalLayout->setObjectName("verticalLayout");
        configWidget = new KUserFeedback::FeedbackConfigWidget(KUserFeedback__FeedbackConfigDialog);
        configWidget->setObjectName("configWidget");

        verticalLayout->addWidget(configWidget);

        buttonBox = new QDialogButtonBox(KUserFeedback__FeedbackConfigDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(KUserFeedback__FeedbackConfigDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, KUserFeedback__FeedbackConfigDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, KUserFeedback__FeedbackConfigDialog, qOverload<>(&QDialog::accept));

        QMetaObject::connectSlotsByName(KUserFeedback__FeedbackConfigDialog);
    } // setupUi

    void retranslateUi(QDialog *KUserFeedback__FeedbackConfigDialog)
    {
        KUserFeedback__FeedbackConfigDialog->setWindowTitle(QCoreApplication::translate("KUserFeedback::FeedbackConfigDialog", "Feedback Settings", nullptr));
    } // retranslateUi

};

} // namespace KUserFeedback

namespace KUserFeedback {
namespace Ui {
    class FeedbackConfigDialog: public Ui_FeedbackConfigDialog {};
} // namespace Ui
} // namespace KUserFeedback

#endif // UI_FEEDBACKCONFIGDIALOG_H
