/****************************************************************************
** Meta object code from reading C++ file 'feedbackconfiguicontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kuserfeedback-6.29.0/src/provider/core/feedbackconfiguicontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'feedbackconfiguicontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KUserFeedback26FeedbackConfigUiControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::FeedbackConfigUiController::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback26FeedbackConfigUiControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::FeedbackConfigUiController",
        "providerChanged",
        "",
        "applicationNameChanged",
        "applicationName",
        "telemetryIndexToMode",
        "KUserFeedback::Provider::TelemetryMode",
        "index",
        "telemetryModeToIndex",
        "mode",
        "telemetryModeName",
        "telemetryIndex",
        "telemetryModeDescription",
        "telemetryModeDetails",
        "telemetryName",
        "telemetryDescription",
        "surveyIndexToInterval",
        "surveyIntervalToIndex",
        "interval",
        "surveyModeDescription",
        "surveyIndex",
        "feedbackProvider",
        "KUserFeedback::Provider*",
        "telemetryModeCount",
        "surveyModeCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'providerChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applicationNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'telemetryIndexToMode'
        QtMocHelpers::MethodData<KUserFeedback::Provider::TelemetryMode(int) const>(5, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::Int, 7 },
        }}),
        // Method 'telemetryModeToIndex'
        QtMocHelpers::MethodData<int(KUserFeedback::Provider::TelemetryMode) const>(8, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 6, 9 },
        }}),
        // Method 'telemetryModeName'
        QtMocHelpers::MethodData<QString(int) const>(10, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'telemetryModeDescription'
        QtMocHelpers::MethodData<QString(int) const>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'telemetryModeDetails'
        QtMocHelpers::MethodData<QString(int) const>(13, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'telemetryName'
        QtMocHelpers::MethodData<QString(KUserFeedback::Provider::TelemetryMode) const>(14, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 6, 9 },
        }}),
        // Method 'telemetryDescription'
        QtMocHelpers::MethodData<QString(KUserFeedback::Provider::TelemetryMode) const>(15, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 6, 9 },
        }}),
        // Method 'surveyIndexToInterval'
        QtMocHelpers::MethodData<int(int) const>(16, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 7 },
        }}),
        // Method 'surveyIntervalToIndex'
        QtMocHelpers::MethodData<int(int) const>(17, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'surveyModeDescription'
        QtMocHelpers::MethodData<QString(int) const>(19, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'feedbackProvider'
        QtMocHelpers::PropertyData<KUserFeedback::Provider*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'telemetryModeCount'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'surveyModeCount'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'applicationName'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FeedbackConfigUiController, qt_meta_tag_ZN13KUserFeedback26FeedbackConfigUiControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::FeedbackConfigUiController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback26FeedbackConfigUiControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback26FeedbackConfigUiControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback26FeedbackConfigUiControllerE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::FeedbackConfigUiController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FeedbackConfigUiController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->providerChanged(); break;
        case 1: _t->applicationNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: { KUserFeedback::Provider::TelemetryMode _r = _t->telemetryIndexToMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KUserFeedback::Provider::TelemetryMode*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->telemetryModeToIndex((*reinterpret_cast<std::add_pointer_t<KUserFeedback::Provider::TelemetryMode>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->telemetryModeName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->telemetryModeDescription((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->telemetryModeDetails((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->telemetryName((*reinterpret_cast<std::add_pointer_t<KUserFeedback::Provider::TelemetryMode>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->telemetryDescription((*reinterpret_cast<std::add_pointer_t<KUserFeedback::Provider::TelemetryMode>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->surveyIndexToInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->surveyIntervalToIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->surveyModeDescription((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KUserFeedback::Provider::TelemetryMode >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KUserFeedback::Provider::TelemetryMode >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KUserFeedback::Provider::TelemetryMode >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FeedbackConfigUiController::*)()>(_a, &FeedbackConfigUiController::providerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FeedbackConfigUiController::*)(const QString & )>(_a, &FeedbackConfigUiController::applicationNameChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KUserFeedback::Provider* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KUserFeedback::Provider**>(_v) = _t->feedbackProvider(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->telemetryModeCount(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->surveyModeCount(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->applicationName(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFeedbackProvider(*reinterpret_cast<KUserFeedback::Provider**>(_v)); break;
        case 3: _t->setApplicationName(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KUserFeedback::FeedbackConfigUiController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::FeedbackConfigUiController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback26FeedbackConfigUiControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KUserFeedback::FeedbackConfigUiController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KUserFeedback::FeedbackConfigUiController::providerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KUserFeedback::FeedbackConfigUiController::applicationNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
