/********************************************************************************
** Form generated from reading UI file 'notificationpopup.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NOTIFICATIONPOPUP_H
#define UI_NOTIFICATIONPOPUP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace KUserFeedback {

class Ui_NotificationPopup
{
public:
    QVBoxLayout *verticalLayout_2;
    QFrame *frame;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *title;
    QPushButton *closeButton;
    QLabel *message;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *actionButton;

    void setupUi(QWidget *KUserFeedback__NotificationPopup)
    {
        if (KUserFeedback__NotificationPopup->objectName().isEmpty())
            KUserFeedback__NotificationPopup->setObjectName("KUserFeedback__NotificationPopup");
        KUserFeedback__NotificationPopup->resize(102, 130);
        verticalLayout_2 = new QVBoxLayout(KUserFeedback__NotificationPopup);
        verticalLayout_2->setObjectName("verticalLayout_2");
        frame = new QFrame(KUserFeedback__NotificationPopup);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        verticalLayout = new QVBoxLayout(frame);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        title = new QLabel(frame);
        title->setObjectName("title");
        QFont font;
        font.setBold(true);
        title->setFont(font);

        horizontalLayout->addWidget(title);

        closeButton = new QPushButton(frame);
        closeButton->setObjectName("closeButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(closeButton->sizePolicy().hasHeightForWidth());
        closeButton->setSizePolicy(sizePolicy);
        closeButton->setFlat(true);

        horizontalLayout->addWidget(closeButton);


        verticalLayout->addLayout(horizontalLayout);

        message = new QLabel(frame);
        message->setObjectName("message");
        message->setWordWrap(true);

        verticalLayout->addWidget(message);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        actionButton = new QPushButton(frame);
        actionButton->setObjectName("actionButton");

        horizontalLayout_2->addWidget(actionButton);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addWidget(frame);


        retranslateUi(KUserFeedback__NotificationPopup);

        QMetaObject::connectSlotsByName(KUserFeedback__NotificationPopup);
    } // setupUi

    void retranslateUi(QWidget *KUserFeedback__NotificationPopup)
    {
        (void)KUserFeedback__NotificationPopup;
    } // retranslateUi

};

} // namespace KUserFeedback

namespace KUserFeedback {
namespace Ui {
    class NotificationPopup: public Ui_NotificationPopup {};
} // namespace Ui
} // namespace KUserFeedback

#endif // UI_NOTIFICATIONPOPUP_H
