/********************************************************************************
** Form generated from reading UI file 'feedbackconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FEEDBACKCONFIGWIDGET_H
#define UI_FEEDBACKCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace KUserFeedback {

class Ui_FeedbackConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_3;
    QLabel *label;
    QSlider *telemetrySlider;
    QStackedWidget *telemetryStack;
    QWidget *noTelemetryPage;
    QVBoxLayout *verticalLayout_2;
    QLabel *noTelemetryLabel;
    QWidget *telemetryPage;
    QVBoxLayout *verticalLayout_3;
    QLabel *telemetryLabel;
    QTextBrowser *telemetryDetails;
    QPushButton *rawTelemetryButton;
    QLabel *auditLogLabel;
    QLabel *label_2;
    QSlider *surveySlider;
    QLabel *surveyLabel;

    void setupUi(QWidget *KUserFeedback__FeedbackConfigWidget)
    {
        if (KUserFeedback__FeedbackConfigWidget->objectName().isEmpty())
            KUserFeedback__FeedbackConfigWidget->setObjectName("KUserFeedback__FeedbackConfigWidget");
        KUserFeedback__FeedbackConfigWidget->resize(400, 308);
        verticalLayout = new QVBoxLayout(KUserFeedback__FeedbackConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        label_3 = new QLabel(KUserFeedback__FeedbackConfigWidget);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(true);

        verticalLayout->addWidget(label_3);

        label = new QLabel(KUserFeedback__FeedbackConfigWidget);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);
        label->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label);

        telemetrySlider = new QSlider(KUserFeedback__FeedbackConfigWidget);
        telemetrySlider->setObjectName("telemetrySlider");
        telemetrySlider->setMaximum(3);
        telemetrySlider->setPageStep(1);
        telemetrySlider->setOrientation(Qt::Horizontal);
        telemetrySlider->setTickPosition(QSlider::TicksBelow);

        verticalLayout->addWidget(telemetrySlider);

        telemetryStack = new QStackedWidget(KUserFeedback__FeedbackConfigWidget);
        telemetryStack->setObjectName("telemetryStack");
        noTelemetryPage = new QWidget();
        noTelemetryPage->setObjectName("noTelemetryPage");
        verticalLayout_2 = new QVBoxLayout(noTelemetryPage);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        noTelemetryLabel = new QLabel(noTelemetryPage);
        noTelemetryLabel->setObjectName("noTelemetryLabel");
        noTelemetryLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        noTelemetryLabel->setWordWrap(true);

        verticalLayout_2->addWidget(noTelemetryLabel);

        telemetryStack->addWidget(noTelemetryPage);
        telemetryPage = new QWidget();
        telemetryPage->setObjectName("telemetryPage");
        verticalLayout_3 = new QVBoxLayout(telemetryPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        telemetryLabel = new QLabel(telemetryPage);
        telemetryLabel->setObjectName("telemetryLabel");
        telemetryLabel->setWordWrap(true);

        verticalLayout_3->addWidget(telemetryLabel);

        telemetryDetails = new QTextBrowser(telemetryPage);
        telemetryDetails->setObjectName("telemetryDetails");

        verticalLayout_3->addWidget(telemetryDetails);

        telemetryStack->addWidget(telemetryPage);

        verticalLayout->addWidget(telemetryStack);

        rawTelemetryButton = new QPushButton(KUserFeedback__FeedbackConfigWidget);
        rawTelemetryButton->setObjectName("rawTelemetryButton");
        rawTelemetryButton->setCheckable(true);
        rawTelemetryButton->setFlat(true);

        verticalLayout->addWidget(rawTelemetryButton);

        auditLogLabel = new QLabel(KUserFeedback__FeedbackConfigWidget);
        auditLogLabel->setObjectName("auditLogLabel");

        verticalLayout->addWidget(auditLogLabel);

        label_2 = new QLabel(KUserFeedback__FeedbackConfigWidget);
        label_2->setObjectName("label_2");
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label_2);

        surveySlider = new QSlider(KUserFeedback__FeedbackConfigWidget);
        surveySlider->setObjectName("surveySlider");
        surveySlider->setMaximum(2);
        surveySlider->setPageStep(1);
        surveySlider->setOrientation(Qt::Horizontal);
        surveySlider->setTickPosition(QSlider::TicksBelow);

        verticalLayout->addWidget(surveySlider);

        surveyLabel = new QLabel(KUserFeedback__FeedbackConfigWidget);
        surveyLabel->setObjectName("surveyLabel");
        surveyLabel->setWordWrap(true);

        verticalLayout->addWidget(surveyLabel);


        retranslateUi(KUserFeedback__FeedbackConfigWidget);

        telemetryStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(KUserFeedback__FeedbackConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *KUserFeedback__FeedbackConfigWidget)
    {
        label_3->setText(QCoreApplication::translate("KUserFeedback::FeedbackConfigWidget", "You can help the development of this software by contributing information on how you use it, so the developers can focus on things that matter to you. Contributing this information is optional and entirely anonymous. We never collect your personal data, files you use, websites you visit, or information that could identify you.", nullptr));
        label->setText(QCoreApplication::translate("KUserFeedback::FeedbackConfigWidget", "Contribute Statistics", nullptr));
        telemetryLabel->setText(QCoreApplication::translate("KUserFeedback::FeedbackConfigWidget", "TextLabel", nullptr));
#if QT_CONFIG(tooltip)
        rawTelemetryButton->setToolTip(QCoreApplication::translate("KUserFeedback::FeedbackConfigWidget", "Show the raw data that is going to be shared.", nullptr));
#endif // QT_CONFIG(tooltip)
        auditLogLabel->setText(QCoreApplication::translate("KUserFeedback::FeedbackConfigWidget", "<a href=\"auditLog\">View previously submitted data...</a>", nullptr));
        label_2->setText(QCoreApplication::translate("KUserFeedback::FeedbackConfigWidget", "Participate in Surveys", nullptr));
        (void)KUserFeedback__FeedbackConfigWidget;
    } // retranslateUi

};

} // namespace KUserFeedback

namespace KUserFeedback {
namespace Ui {
    class FeedbackConfigWidget: public Ui_FeedbackConfigWidget {};
} // namespace Ui
} // namespace KUserFeedback

#endif // UI_FEEDBACKCONFIGWIDGET_H
