/********************************************************************************
** Form generated from reading UI file 'auditlogbrowserdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUDITLOGBROWSERDIALOG_H
#define UI_AUDITLOGBROWSERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>

namespace KUserFeedback {

class Ui_AuditLogBrowserDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *logEntryBox;
    QTextBrowser *logEntryView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *KUserFeedback__AuditLogBrowserDialog)
    {
        if (KUserFeedback__AuditLogBrowserDialog->objectName().isEmpty())
            KUserFeedback__AuditLogBrowserDialog->setObjectName("KUserFeedback__AuditLogBrowserDialog");
        KUserFeedback__AuditLogBrowserDialog->resize(560, 720);
        verticalLayout = new QVBoxLayout(KUserFeedback__AuditLogBrowserDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(KUserFeedback__AuditLogBrowserDialog);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        logEntryBox = new QComboBox(KUserFeedback__AuditLogBrowserDialog);
        logEntryBox->setObjectName("logEntryBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(logEntryBox->sizePolicy().hasHeightForWidth());
        logEntryBox->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(logEntryBox);


        verticalLayout->addLayout(horizontalLayout);

        logEntryView = new QTextBrowser(KUserFeedback__AuditLogBrowserDialog);
        logEntryView->setObjectName("logEntryView");

        verticalLayout->addWidget(logEntryView);

        buttonBox = new QDialogButtonBox(KUserFeedback__AuditLogBrowserDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Discard);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(logEntryBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KUserFeedback__AuditLogBrowserDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, KUserFeedback__AuditLogBrowserDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, KUserFeedback__AuditLogBrowserDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(KUserFeedback__AuditLogBrowserDialog);
    } // setupUi

    void retranslateUi(QDialog *KUserFeedback__AuditLogBrowserDialog)
    {
        KUserFeedback__AuditLogBrowserDialog->setWindowTitle(QCoreApplication::translate("KUserFeedback::AuditLogBrowserDialog", "Submitted Data", nullptr));
        label->setText(QCoreApplication::translate("KUserFeedback::AuditLogBrowserDialog", "Da&ta Submission:", nullptr));
    } // retranslateUi

};

} // namespace KUserFeedback

namespace KUserFeedback {
namespace Ui {
    class AuditLogBrowserDialog: public Ui_AuditLogBrowserDialog {};
} // namespace Ui
} // namespace KUserFeedback

#endif // UI_AUDITLOGBROWSERDIALOG_H
