/****************************************************************************
** Meta object code from reading C++ file 'qmldatasources.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kuserfeedback-6.29.0/src/provider/qml/qmldatasources.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmldatasources.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KUserFeedback27QmlApplicationVersionSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlApplicationVersionSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback27QmlApplicationVersionSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlApplicationVersionSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlApplicationVersionSource, qt_meta_tag_ZN13KUserFeedback27QmlApplicationVersionSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlApplicationVersionSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback27QmlApplicationVersionSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback27QmlApplicationVersionSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback27QmlApplicationVersionSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlApplicationVersionSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlApplicationVersionSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlApplicationVersionSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlApplicationVersionSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback27QmlApplicationVersionSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlApplicationVersionSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KUserFeedback21QmlCompilerInfoSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlCompilerInfoSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback21QmlCompilerInfoSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlCompilerInfoSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlCompilerInfoSource, qt_meta_tag_ZN13KUserFeedback21QmlCompilerInfoSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlCompilerInfoSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback21QmlCompilerInfoSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback21QmlCompilerInfoSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback21QmlCompilerInfoSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlCompilerInfoSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlCompilerInfoSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlCompilerInfoSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlCompilerInfoSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback21QmlCompilerInfoSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlCompilerInfoSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KUserFeedback16QmlCpuInfoSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlCpuInfoSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback16QmlCpuInfoSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlCpuInfoSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlCpuInfoSource, qt_meta_tag_ZN13KUserFeedback16QmlCpuInfoSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlCpuInfoSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback16QmlCpuInfoSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback16QmlCpuInfoSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback16QmlCpuInfoSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlCpuInfoSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlCpuInfoSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlCpuInfoSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlCpuInfoSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback16QmlCpuInfoSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlCpuInfoSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KUserFeedback19QmlLocaleInfoSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlLocaleInfoSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback19QmlLocaleInfoSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlLocaleInfoSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlLocaleInfoSource, qt_meta_tag_ZN13KUserFeedback19QmlLocaleInfoSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlLocaleInfoSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlLocaleInfoSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlLocaleInfoSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback19QmlLocaleInfoSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlLocaleInfoSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlLocaleInfoSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlLocaleInfoSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlLocaleInfoSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlLocaleInfoSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlLocaleInfoSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KUserFeedback19QmlOpenGLInfoSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlOpenGLInfoSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback19QmlOpenGLInfoSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlOpenGLInfoSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlOpenGLInfoSource, qt_meta_tag_ZN13KUserFeedback19QmlOpenGLInfoSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlOpenGLInfoSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlOpenGLInfoSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlOpenGLInfoSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback19QmlOpenGLInfoSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlOpenGLInfoSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlOpenGLInfoSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlOpenGLInfoSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlOpenGLInfoSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlOpenGLInfoSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlOpenGLInfoSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KUserFeedback21QmlPlatformInfoSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlPlatformInfoSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback21QmlPlatformInfoSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlPlatformInfoSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlPlatformInfoSource, qt_meta_tag_ZN13KUserFeedback21QmlPlatformInfoSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlPlatformInfoSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback21QmlPlatformInfoSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback21QmlPlatformInfoSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback21QmlPlatformInfoSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlPlatformInfoSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlPlatformInfoSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlPlatformInfoSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlPlatformInfoSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback21QmlPlatformInfoSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlPlatformInfoSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KUserFeedback16QmlQPAInfoSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlQPAInfoSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback16QmlQPAInfoSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlQPAInfoSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlQPAInfoSource, qt_meta_tag_ZN13KUserFeedback16QmlQPAInfoSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlQPAInfoSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback16QmlQPAInfoSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback16QmlQPAInfoSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback16QmlQPAInfoSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlQPAInfoSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlQPAInfoSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlQPAInfoSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlQPAInfoSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback16QmlQPAInfoSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlQPAInfoSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KUserFeedback18QmlQtVersionSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlQtVersionSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback18QmlQtVersionSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlQtVersionSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlQtVersionSource, qt_meta_tag_ZN13KUserFeedback18QmlQtVersionSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlQtVersionSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback18QmlQtVersionSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback18QmlQtVersionSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback18QmlQtVersionSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlQtVersionSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlQtVersionSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlQtVersionSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlQtVersionSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback18QmlQtVersionSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlQtVersionSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KUserFeedback19QmlScreenInfoSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlScreenInfoSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback19QmlScreenInfoSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlScreenInfoSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlScreenInfoSource, qt_meta_tag_ZN13KUserFeedback19QmlScreenInfoSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlScreenInfoSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlScreenInfoSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlScreenInfoSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback19QmlScreenInfoSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlScreenInfoSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlScreenInfoSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlScreenInfoSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlScreenInfoSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlScreenInfoSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlScreenInfoSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KUserFeedback19QmlStartCountSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlStartCountSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback19QmlStartCountSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlStartCountSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlStartCountSource, qt_meta_tag_ZN13KUserFeedback19QmlStartCountSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlStartCountSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlStartCountSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlStartCountSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback19QmlStartCountSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlStartCountSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlStartCountSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlStartCountSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlStartCountSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback19QmlStartCountSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlStartCountSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13KUserFeedback18QmlUsageTimeSourceE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::QmlUsageTimeSource::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback18QmlUsageTimeSourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::QmlUsageTimeSource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlUsageTimeSource, qt_meta_tag_ZN13KUserFeedback18QmlUsageTimeSourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::QmlUsageTimeSource::staticMetaObject = { {
    QMetaObject::SuperData::link<QmlAbstractDataSource::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback18QmlUsageTimeSourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback18QmlUsageTimeSourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback18QmlUsageTimeSourceE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::QmlUsageTimeSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlUsageTimeSource *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KUserFeedback::QmlUsageTimeSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::QmlUsageTimeSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback18QmlUsageTimeSourceE_t>.strings))
        return static_cast<void*>(this);
    return QmlAbstractDataSource::qt_metacast(_clname);
}

int KUserFeedback::QmlUsageTimeSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QmlAbstractDataSource::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
