/****************************************************************************
** Meta object code from reading C++ file 'provider.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kuserfeedback-6.29.0/src/provider/core/provider.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'provider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KUserFeedback8ProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto KUserFeedback::Provider::qt_create_metaobjectdata<qt_meta_tag_ZN13KUserFeedback8ProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KUserFeedback::Provider",
        "surveyAvailable",
        "",
        "KUserFeedback::SurveyInfo",
        "survey",
        "showEncouragementMessage",
        "surveyIntervalChanged",
        "telemetryModeChanged",
        "providerSettingsChanged",
        "enabledChanged",
        "dataSourcesChanged",
        "submit",
        "surveyCompleted",
        "info",
        "load",
        "store",
        "jsonData",
        "KUserFeedback::Provider::TelemetryMode",
        "selectSurvey",
        "enabled",
        "surveyInterval",
        "telemetryMode",
        "TelemetryMode",
        "productIdentifier",
        "feedbackServer",
        "QUrl",
        "submissionInterval",
        "applicationStartsUntilEncouragement",
        "applicationUsageTimeUntilEncouragement",
        "encouragementDelay",
        "encouragementInterval",
        "describeDataSources",
        "NoTelemetry",
        "BasicSystemInformation",
        "BasicUsageStatistics",
        "DetailedSystemInformation",
        "DetailedUsageStatistics"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'surveyAvailable'
        QtMocHelpers::SignalData<void(const KUserFeedback::SurveyInfo &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'showEncouragementMessage'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'surveyIntervalChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'telemetryModeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'providerSettingsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataSourcesChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'submit'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'surveyCompleted'
        QtMocHelpers::SlotData<void(const KUserFeedback::SurveyInfo &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 13 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'store'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jsonData'
        QtMocHelpers::SlotData<QByteArray(KUserFeedback::Provider::TelemetryMode)>(16, 2, QMC::AccessPrivate, QMetaType::QByteArray, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Slot 'selectSurvey'
        QtMocHelpers::SlotData<bool(const KUserFeedback::SurveyInfo &)>(18, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 3, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'surveyInterval'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'telemetryMode'
        QtMocHelpers::PropertyData<enum TelemetryMode>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'productIdentifier'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'feedbackServer'
        QtMocHelpers::PropertyData<QUrl>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'submissionInterval'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'applicationStartsUntilEncouragement'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'applicationUsageTimeUntilEncouragement'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'encouragementDelay'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'encouragementInterval'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'describeDataSources'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TelemetryMode'
        QtMocHelpers::EnumData<enum TelemetryMode>(22, 22, QMC::EnumFlags{}).add({
            {   32, TelemetryMode::NoTelemetry },
            {   33, TelemetryMode::BasicSystemInformation },
            {   34, TelemetryMode::BasicUsageStatistics },
            {   35, TelemetryMode::DetailedSystemInformation },
            {   36, TelemetryMode::DetailedUsageStatistics },
        }),
    };
    return QtMocHelpers::metaObjectData<Provider, qt_meta_tag_ZN13KUserFeedback8ProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KUserFeedback::Provider::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback8ProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback8ProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KUserFeedback8ProviderE_t>.metaTypes,
    nullptr
} };

void KUserFeedback::Provider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Provider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->surveyAvailable((*reinterpret_cast<std::add_pointer_t<KUserFeedback::SurveyInfo>>(_a[1]))); break;
        case 1: _t->showEncouragementMessage(); break;
        case 2: _t->surveyIntervalChanged(); break;
        case 3: _t->telemetryModeChanged(); break;
        case 4: _t->providerSettingsChanged(); break;
        case 5: _t->enabledChanged(); break;
        case 6: _t->dataSourcesChanged(); break;
        case 7: _t->submit(); break;
        case 8: _t->surveyCompleted((*reinterpret_cast<std::add_pointer_t<KUserFeedback::SurveyInfo>>(_a[1]))); break;
        case 9: _t->load(); break;
        case 10: _t->store(); break;
        case 11: { QByteArray _r = _t->d->jsonData((*reinterpret_cast<std::add_pointer_t<KUserFeedback::Provider::TelemetryMode>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->d->selectSurvey((*reinterpret_cast<std::add_pointer_t<KUserFeedback::SurveyInfo>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KUserFeedback::Provider::TelemetryMode >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Provider::*)(const KUserFeedback::SurveyInfo & )>(_a, &Provider::surveyAvailable, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Provider::*)()>(_a, &Provider::showEncouragementMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Provider::*)()>(_a, &Provider::surveyIntervalChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Provider::*)()>(_a, &Provider::telemetryModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Provider::*)()>(_a, &Provider::providerSettingsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Provider::*)()>(_a, &Provider::enabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Provider::*)()>(_a, &Provider::dataSourcesChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->surveyInterval(); break;
        case 2: *reinterpret_cast<enum TelemetryMode*>(_v) = _t->telemetryMode(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->productIdentifier(); break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->feedbackServer(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->submissionInterval(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->applicationStartsUntilEncouragement(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->applicationUsageTimeUntilEncouragement(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->encouragementDelay(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->encouragementInterval(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->describeDataSources(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setSurveyInterval(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setTelemetryMode(*reinterpret_cast<enum TelemetryMode*>(_v)); break;
        case 3: _t->setProductIdentifier(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setFeedbackServer(*reinterpret_cast<QUrl*>(_v)); break;
        case 5: _t->setSubmissionInterval(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setApplicationStartsUntilEncouragement(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setApplicationUsageTimeUntilEncouragement(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setEncouragementDelay(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setEncouragementInterval(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KUserFeedback::Provider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUserFeedback::Provider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KUserFeedback8ProviderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KUserFeedback::Provider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KUserFeedback::Provider::surveyAvailable(const KUserFeedback::SurveyInfo & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KUserFeedback::Provider::showEncouragementMessage()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KUserFeedback::Provider::surveyIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KUserFeedback::Provider::telemetryModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KUserFeedback::Provider::providerSettingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KUserFeedback::Provider::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KUserFeedback::Provider::dataSourcesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
